indchisq: Independence test

View source: R/indchisq.R

indchisqR Documentation

Independence test

Description

This function is for the independence test of two categorical variables

Usage

indchisq(O, conf.level = 0.95)

Arguments

O

an observed matrix has a rows and b columns

conf.level

confidence level for testing hypothesis, default is 0.95, user can change to 0.90 or otherwise

Value

output for the independence test

References

Plackett, R. L. (1983). Karl Pearson and the Chi-Squared Test. International Statistical Review / Revue Internationale de Statistique, 51(1), 59–72. <doi.org/10.2307/1402731>.

Examples

v <- c(80,60,150,50,40,20)
X<- matrix(v,ncol=2,byrow = TRUE)  # 3x2
indchisq(X)


Mychisq documentation built on June 22, 2026, 9:08 a.m.

Related to indchisq in Mychisq...