sigmaCI: Confidence interval for the population standard deviation

View source: R/sigmaCI.R

sigmaCIR Documentation

Confidence interval for the population standard deviation

Description

A function 'sigmaCI()' is used to compute a confidence interval of the population standard deviation when given a numeric vector

Usage

sigmaCI(x, conf.level = 0.95)

Arguments

x

a numeric vector

conf.level

a confidence level, default is 0.95; the user can change to 0.90 or otherwise

Value

a confidence interval of the population standard deviation

References

Rattanalertnusorn, A. (2024). R and its application (3rd ed.). TPN press. <https://www.researchgate.net/publication/371944275_porkaermxarlaeakarprayuktchingan_R_and_its_applications>.

Examples

heigth <- c(155.5, 165.5, 170, 164.5, 180, 162, 173, 158.5, 168.5, 175, 164.5, 167)
sigmaCI(x=heigth,conf.level = 0.90)


Mychisq documentation built on June 22, 2026, 9:08 a.m.

Related to sigmaCI in Mychisq...