sigmatest: Hypothesis testing for the population variance

View source: R/sigmatest.R

sigmatestR Documentation

Hypothesis testing for the population variance

Description

The function 'sigmatest()' is used to test the hypothesis about the population variance

Usage

sigmatest(
  x,
  sigma,
  alternative = c("two.sided"),
  conf.level = 0.95,
  verbose = TRUE
)

Arguments

x

a numeric vector

sigma

a population standard deviation under the null hypothesis

alternative

an alternative hypothesis, default is "two.sided"; the user can change to "greater" or "less"

conf.level

a confidence level for hypothesis testing, default is 0.95; the user can change to 0.90 or otherwise

verbose

a special variable is used for protected unexpected print output; the default is TRUE, do NOT change

Value

output of one sample Chi-squared test for variance

References

Rattanalertnusorn, A. (2024). R and its application (3rd ed.). TPN press. <https://www.researchgate.net/publication/371944275_porkaermxarlaeakarprayuktchingan_R_and_its_applications>.

Examples

heigth <- c(155.5, 165.5, 170, 164.5, 180, 162, 173, 158.5, 168.5, 175, 164.5, 167)
sigmatest(x=heigth, sigma = 3, alternative = "two.sided", conf.level = 0.95)


Mychisq documentation built on June 22, 2026, 9:08 a.m.

Related to sigmatest in Mychisq...