| sigmatest | R Documentation |
The function 'sigmatest()' is used to test the hypothesis about the population variance
sigmatest(
x,
sigma,
alternative = c("two.sided"),
conf.level = 0.95,
verbose = TRUE
)
x |
a numeric vector |
sigma |
a population standard deviation under the null hypothesis |
alternative |
an alternative hypothesis, default is "two.sided"; the user can change to "greater" or "less" |
conf.level |
a confidence level for hypothesis testing, default is |
verbose |
a special variable is used for protected unexpected print output; the default is TRUE, do NOT change |
output of one sample Chi-squared test for variance
Rattanalertnusorn, A. (2024). R and its application (3rd ed.). TPN press. <https://www.researchgate.net/publication/371944275_porkaermxarlaeakarprayuktchingan_R_and_its_applications>.
heigth <- c(155.5, 165.5, 170, 164.5, 180, 162, 173, 158.5, 168.5, 175, 164.5, 167)
sigmatest(x=heigth, sigma = 3, alternative = "two.sided", conf.level = 0.95)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.